#!/bin/sh
#
# Simple installer to help installing GOpdc
#
APPLNAM="gopdc"
MY_CONFIGDIR="/etc"
MY_INSTDIR="/usr/share/gopdc"
INSTPREFIX="/"
FILESTOCOPY="scripts/functions.php4 scripts/gopdc.php4 scripts/config.inc scripts/populate.php4 scripts/gopdc_helper.php4"
DOCS="contrib/smb.conf contrib/machine_group.ldif doc/README.txt doc/README.helper doc/README.populate doc/changes doc/TODO"
CONFS="config/gopdc.xml"

function rewriteconfig(){
	my_file="$1"
	my_oldvalue="$2"
	my_value="$3"
	ed $my_file 2>/dev/null <<EOF
	,s%$my_oldvalue%$my_value%g
wq
EOF
}

function usage(){
	cat <<EOF
Very simple installer for GOpdc
possible options are:
-instprefix     Installation prefix (needed for package building)
EOF
}

function copyfile(){
	sourcef="$1"
	path="$2"
	cp "$1" "$2"
}

[ ! "$1" ] && usage && exit 1

eval set -- "$@"
for i in "$@" ; do
	case "$1" in
		-instprefix)
			if [ -z "$2" ]; then
				echo "No installation prefix set"
				exit 1
			else
				unset INSTPREFIX
				INSTPREFIX="$2"
			fi
			shift 2
			;;
	esac
done

echo "Installing GOpdc to ${INSTPREFIX}:"
mkdir -p ${INSTPREFIX}/${MY_INSTDIR}
for file in $FILESTOCOPY; do
	copyfile $file ${INSTPREFIX}/${MY_INSTDIR}/
	file_realname=`basename $file`
	rewriteconfig ${INSTPREFIX}/${MY_INSTDIR}/${file_realname} "config/gopdc.xml" "${MY_CONFIGDIR}/gopdc.xml"
	rewriteconfig ${INSTPREFIX}/${MY_INSTDIR}/${file_realname} "./scripts/" "${MY_INSTDIR}/"
done
mkdir -p ${INSTPREFIX}/${MY_CONFIGDIR}
for file in $CONFS; do
	copyfile $file ${INSTPREFIX}/${MY_CONFIGDIR}/
	conf_realname=`basename $file`
	rewriteconfig ${INSTPREFIX}/${MY_CONFIGDIR}/${conf_realname} "./scripts/" "${MY_INSTDIR}/"
	rewriteconfig ${INSTPREFIX}/${MY_CONFIGDIR}/${conf_realname} "./gopdc.log" "/var/log/gopdc.log"
done
mkdir -p ${INSTPREFIX}/usr/share/doc/${APPLNAM}
for file in $DOCS; do
	copyfile $file ${INSTPREFIX}/usr/share/doc/${APPLNAM}/
done

